@@ -33,7 +33,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.37';
+our $VERSION = '2.38';
 
 =head1 SYNOPSIS
 
@@ -168,6 +168,32 @@ You shouldn't be calling these directly.
 
 =cut
 
+=head2 jobref
+
+Array of arrays details slurm/process/scheduler job id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
+
+=cut
+
+has 'jobref' => (
+    traits  => ['NoGetopt'],
+    is => 'rw',
+    isa => 'ArrayRef',
+    default => sub { [ [] ]  },
+);
+
+=head2 wait
+
+Boolean value indicates any job dependencies
+
+=cut
+
+has 'wait' => (
+    traits  => ['NoGetopt'],
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+);
+
 has 'cmd' => (
     traits  => ['String', 'NoGetopt'],
     is => 'rw',
@@ -231,8 +257,10 @@ sub set_logdir{
     my $logdir;
     $logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
 
+    $DB::single=2;
 #    #forget this it makes the log files too log
     $logdir =~ s/\.log$//;
+    #$logdir =~ s/\.md//g;
 
 #    #Don't want to overwrite existing logdirs
 #    #Actually don't care because all CMD files should be fine
@@ -258,6 +286,7 @@ sub set_logfile{
     my $dt = DateTime->now();
     $dt =~ s/[^\w]/_/g;
     return "$dt.log";
+    #return $dt;
 }
 
 =head2 init_log
@@ -293,6 +322,7 @@ sub run_command_threads{
     my $self = shift;
 
     my $pid = $self->threads->start($self->cmd) and return;
+    push(@{$self->jobref->[-1]}, $pid);
 
     my $exitcode = $self->_log_commands($pid);
 
@@ -315,6 +345,7 @@ sub run_command_mce{
     $DB::single=2;
 
     #Mce doesn't take exitcode to end
+    push(@{$self->jobref->[-1]}, $pid);
     $self->_log_commands($pid);
 
     return;
@@ -348,6 +379,8 @@ sub _log_commands {
     #Create new log for each job
     $self->logfile($self->set_logfile);
     $self->prepend_logfile("CMD".$self->counter."_PID_$pid"."_DT_");
+    $DB::single=2;
+
     my $logger = $self->init_log;
 
     #Start running job
